"""Entry"""

from .version import __version__
from .entry import PipenCliRunPlugin
from .pipeline import Pipeline, process
